# AutoGen 学习项目

## 项目简介
这是一个使用微软AutoGen框架的学习项目，用于探索和研究自动生成AI代理的开发与应用。

## 参考链接
- 官方文档: [https://microsoft.github.io/autogen/stable//index.html](https://microsoft.github.io/autogen/stable//index.html)

## TODO
- [x] 搭建基础AutoGen环境
- [x] 创建第一个对话代理
- [x] 实现多代理协作场景
- [x] 编写使用示例和文档
- [x] 多任务不同编排方案GraphFlow
- [ ] Autogen的状态管理
- [ ] Autogen支持分布式
- [ ] 添加自定义功能模块
- [ ] 工具调用项目实战案例
- [ ] 性能优化与调优
